ZenServiceExtensions class
Service extensions for DevTools integration
These extensions allow the DevTools extension to query the running app for scope hierarchy, dependencies, and other debug information.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerExtensions(
) → void - Register all Zenify service extensions