isFetching property
bool
get
isFetching
Whether this query is currently fetching data from the network
Implementation
bool get isFetching => fetchStatus.value == ZenQueryFetchStatus.fetching;
Whether this query is currently fetching data from the network
bool get isFetching => fetchStatus.value == ZenQueryFetchStatus.fetching;