RxCircuitBreaker class

Circuit breaker for reactive operations

Constructors

RxCircuitBreaker({required int failureThreshold, required Duration resetTimeout})

Properties

failureThreshold → int
final
hashCode → int
The hash code for this object.
no setterinherited
resetTimeout → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → Map<String, dynamic>
Get current state
no setter

Methods

execute<T>(RxResult<T> operation()) → RxResult<T>
Execute operation with circuit breaker protection
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited