RxTimingExtensions<T> extension
Timing extensions for reactive values
- on
-
- Rx<
T>
- Rx<
Methods
-
buffer(
Duration duration, void callback(List< T> values)) → void -
Available on Rx<
Buffer value changes for specified durationT> , provided by the RxTimingExtensions extension -
debounce(
Duration duration, void callback(T value)) → void -
Available on Rx<
Debounce value changes - callback is called after duration of inactivityT> , provided by the RxTimingExtensions extension -
delay(
Duration duration, void callback(T value)) → void -
Available on Rx<
Delay value changes by specified durationT> , provided by the RxTimingExtensions extension -
distinct(
void callback(T value), [bool equals(T previous, T current)?]) → void -
Available on Rx<
Only call callback when value actually changes (distinct)T> , provided by the RxTimingExtensions extension -
listenMapped<
R> (R transformer(T value), void callback(R value)) → void -
Available on Rx<
Transform value before calling callback. Named listenMapped to distinguish from RxComputedExtensions.map which returns a computed value rather than registering a callback.T> , provided by the RxTimingExtensions extension -
listenWhere(
bool condition(T value), void callback(T value)) → void -
Available on Rx<
Only call callback when value meets condition. Named listenWhere to distinguish from RxComputedExtensions.where which returns a computed value rather than registering a callback.T> , provided by the RxTimingExtensions extension -
sample(
Duration interval, void callback(T value)) → StreamSubscription< T> -
Available on Rx<
Sample value changes at regular intervalsT> , provided by the RxTimingExtensions extension -
skipFirst(
int count, void callback(T value)) → void -
Available on Rx<
Skip first n value changes (callback-style listener) NOTE: NamedT> , provided by the RxTimingExtensions extensionskipFirstto avoid ambiguity withRxTransformations.skipwhich returns a computed value instead of registering a callback. -
takeFirst(
int count, void callback(T value)) → void -
Available on Rx<
Take only first n value changes (callback-style listener) NOTE: NamedT> , provided by the RxTimingExtensions extensiontakeFirstto avoid ambiguity withRxTransformations.takewhich returns a computed value instead of registering a callback. -
throttle(
Duration duration, void callback(T value)) → void -
Available on Rx<
Throttle value changes - callback is called at most once per durationT> , provided by the RxTimingExtensions extension