RxTransformations<T> extension
Transformation extensions for reactive values
- on
-
- Rx<
T>
- Rx<
Methods
-
asNullable(
) → RxComputed< T?> -
Available on Rx<
Convert to nullable typeT> , provided by the RxTransformations extension -
combineLatest<
U, R> (Rx< U> other, R combiner(T, U)) → RxComputed<R> -
Available on Rx<
Combine with another reactive valueT> , provided by the RxTransformations extension -
distinctMap<
R> (R mapper(T)) → RxComputed< R> -
Available on Rx<
Create a reactive value that only updates when the mapped value changesT> , provided by the RxTransformations extension -
filter(
bool predicate(T)) → RxComputed< T?> -
Available on Rx<
Filter values based on a predicateT> , provided by the RxTransformations extension -
skip(
int count) → RxComputed< T?> -
Available on Rx<
Skip the first n values, returns null until exhausted. Always accesses value so dependency tracking is maintained, fixing a bug where the computed became permanently dead during the skip phase (since it never accessed value and thus tracked no dependencies).T> , provided by the RxTransformations extension -
switchMap<
R> (RxComputed< R> mapper(T)) → RxComputed<R> -
Available on Rx<
Switch to a new reactive value based on current valueT> , provided by the RxTransformations extension -
take(
int count) → RxComputed< T?> -
Available on Rx<
Take the first n values, returns null once exhausted. Always accesses value so dependency tracking is maintained, ensuring re-evaluation when the source changes.T> , provided by the RxTransformations extension -
transform<
R> (R mapper(T)) → RxComputed< R> -
Available on Rx<
Transform this reactive value to another typeT> , provided by the RxTransformations extension