skip method

RxComputed<T?> skip(
  1. int count
)

Skip the first n values, returns null until exhausted. Always accesses value so dependency tracking is maintained, fixing a bug where the computed became permanently dead during the skip phase (since it never accessed value and thus tracked no dependencies).

Implementation

RxComputed<T?> skip(int count) {
  int skipped = 0;
  return computed(() {
    final current = value; // Always access to maintain dependency tracking
    if (skipped < count) {
      skipped++;
      return null;
    }
    return current;
  });
}