error property
Builder for the error state with a retry callback. Defaults to the built-in ZenQueryBuilder error UI.
Implementation
final Widget Function(Object error, VoidCallback retry)? error;
Builder for the error state with a retry callback. Defaults to the built-in ZenQueryBuilder error UI.
final Widget Function(Object error, VoidCallback retry)? error;