showStaleData property
Whether to show stale data while a background refetch is in progress. Defaults to true.
Implementation
final bool showStaleData;
Whether to show stale data while a background refetch is in progress. Defaults to true.
final bool showStaleData;