build abstract method
Build the widget.
Use the controller getter to access the resolved controller. It is always non-nullable inside build.
Implementation
Widget build(BuildContext context);
Build the widget.
Use the controller getter to access the resolved controller. It is always non-nullable inside build.
Widget build(BuildContext context);