create<T extends Object> static method
Convenience method to create a scope with a single controller.
This is the recommended way to scope a single controller to a route or widget tree.
Implementation
static ZenProvider create<T extends Object>({
Key? key,
required T Function() create,
String? scopeName,
required Widget child,
}) {
return ZenProvider(
key: key,
moduleBuilder: () =>
_SingleItemModule<T>(create, scopeName ?? 'Scope_${T.toString()}'),
child: child,
);
}