mayFindScope method

  1. @Deprecated('Use zenScope instead')
ZenScope? mayFindScope()

Finds the nearest ZenScope above this context, or returns null if none is found.

Similar to findScope, but returns null instead of throwing an exception if no scope is found.

Implementation

@Deprecated('Use zenScope instead')
ZenScope? mayFindScope() => zenScope;