widgets/widgets library

Classes

Obx
Deprecated alias for ZenObserver.
ZenBuilder<T extends ZenController>
Widget that automatically manages a ZenController's lifecycle
ZenConsumer<T>
Widget that efficiently accesses dependencies from the current scope with automatic caching to avoid repeated lookups on rebuilds
ZenEffectBuilder<T>
A widget that responds to different states of a ZenEffect.
ZenObserver
The canonical Zenify reactive observer widget.
ZenRoute
Route-scoped dependency injection widget
ZenScopeWidget
Widget-scoped dependency injection provider
ZenView<T extends ZenController>
Base class for screens and pages that own a ZenController.

Extensions

ZenScopeExtension on BuildContext
Extension methods for BuildContext to find a ZenScope.
ZenViewContextExtensions on BuildContext
Context extension for resolving a ZenController from within any widget.
ZenViewExtension on ZenView<T>
Provides access to the ZenController resolved by this ZenView.