createController property
T Function()?
get
createController
Optional factory to create the controller if it is not already registered.
The created controller is placed into the nearest ZenScope (or global DI if no scope ancestor is present).
Implementation
T Function()? get createController => null;